==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/pl.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokumenty",
    "Can't create document" : "Nie można utworzyć dokumentu",
    "You don't have permission to rename this document" : "Nie masz uprawnień do zmiany nazwy tego dokumentu",
    "Directory saved successfully." : "Katalog zapisany poprawnie.",
    "An error occurred while changing directory." : "Pojawił się błąd podczas zmiany katalogu.",
    "Saved" : "Zapisano",
    "Format filter server is down or misconfigured" : "Serwer filtrów formatów jest niedostępny lub nieprawidłowo skonfigurowany",
    "Conversion failed. Check log for details." : "Konwersja nieudana. Sprawdź szczegóły w logu.",
    "Saving..." : "Zapisywanie...",
    "Failed to load documents." : "Nie można wczytać dokumentów.",
    "No documents were found. Upload or create a document to get started!" : "Nie znaleziono dokumentów. Wyślij lub stwórz dokument aby rozpocząć!",
    "No connection to server. Trying to reconnect." : "Nie połączono z serwerem. Próba ponownego łączenia. ",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Opuszczając tę stronę w trybie Edytor może spowodować niezapisanie danych. Zaleca się zamiast tego użyć przycisk 'Zamknij'.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Nie można załadować tego dokumentu. Proszę sprawdzić, czy można go otworzyć w zewnętrznym edytorze odt. Może to również oznaczać, że dokument został niedawno zmieniony na nieudostępniony lub usunięty.",
    "Save" : "Zapisz",
    "Loading documents..." : "Ładowanie dokumentów...",
    "'.' is an invalid file name." : "„.” jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nieprawidłowa nazwa. Znaki '\\', '/', '<', '>', ':', '\"', '|', '?' oraz '*' są niedozwolone.",
    "Align Left" : "Wyrównaj do lewej",
    "Alignment" : "Wyrównanie",
    "Align Right" : "Wyrównaj do prawej",
    "Annotate" : "Adnotacje",
    "Background" : "Tło",
    "Bold" : "Pogrubienie",
    "Bottom" : "Dół",
    "Cancel" : "Anuluj",
    "Center" : "Do środka",
    "Clone" : "Klonuj",
    "Clone this Style" : "Klonuj ten styl",
    "Close" : "Zamknij",
    "Color" : "Kolor",
    "Create" : "Utwórz",
    "Decrease Indent" : "Zmniejsz wcięcie",
    "Default Style" : "Domyślny styl",
    "Delete" : "Usuń",
    "Family" : "Rodzina",
    "Font" : "Czcionka",
    "Font Effects" : "Efekty czcionki",
    "Format" : "Format",
    "Increase Indent" : "Zwiększ wcięcie",
    "Insert Image" : "Wstaw obraz",
    "Invite Members" : "Zaproś członków",
    "Italic" : "Kursywa",
    "Justified" : "Wyjustowany",
    "Justify" : "Wyjustuj",
    "Left" : "Lewo",
    "Loading" : "Ładuję",
    "Members" : "Członkowie",
    "New Name:" : "Nowa nazwa:",
    "OK" : "OK",
    "Open" : "Otwórz",
    "Options" : "Opcje",
    "Paragraph..." : "Akapit...",
    "Paragraph Styles" : "Style akapitów",
    "Redo" : "Ponów",
    "Right" : "Prawo",
    "Size" : "Rozmiar",
    "Spacing" : "Odstępy",
    "Strikethrough" : "Przekreślenie",
    "Style" : "Style",
    "Text" : "Tekst",
    "Top" : "Góra",
    "Underline" : "Podkreślenie",
    "Undo" : "Cofnij",
    "Unknown Author" : "Nieznany autor",
    "Edit" : "Edytuj",
    "Share" : "Udostępnij",
    "guest" : "gość",
    "MS Word support (requires openOffice/libreOffice)" : "Wsparcie MS Word (wymaga openOffice/libreOffice)",
    "Local" : "Lokalny",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice jest zainstalowany na tej maszynie. Ścieżka do binariów jest podawana przez preview_libreoffice_path w config.php",
    "External" : "Zewnętrzny",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice jest zainstalowany na zewnętrznym systemie z uruchomionym serwerem konwersji formatów",
    "Disabled" : "Wyłączone",
    "No MS Word support" : "Brak wsparcia dla MS Word",
    "scheme://domain.tld[:port]" : "schemat://domena.tld[:port]",
    "Server URL" : "URL serwera",
    "Apply and test" : "Zastosuj i przetestuj",
    "New document" : "Nowy dokument",
    "Upload (max. %s)" : "Wysyłka (max. %s)",
    "Upload" : "Wyślij",
    "Save new documents to" : "Zapisz nowy dokument do",
    "Wrong password. Please retry." : "Złe hasło. Spróbuj ponownie.",
    "Password" : "Hasło",
    "Guest %s" : "Gość %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Ten link już wygasła lub nigdy nie istniał. Proszę skontaktuj się z osobą, która udostępniła ci link, aby uzyskać szczegółowe informacje.",
    "Advanced feature-set" : "Zaawansowany zestaw funkcji",
    "(Unstable)" : "(Niestabilne)"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-app-documents-1%3A9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/pl.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokumenty",
    "Can't create document" : "Nie można utworzyć dokumentu",
    "You don't have permission to rename this document" : "Nie masz uprawnień do zmiany nazwy tego dokumentu",
    "Directory saved successfully." : "Katalog zapisany poprawnie.",
    "An error occurred while changing directory." : "Pojawił się błąd podczas zmiany katalogu.",
    "Saved" : "Zapisano",
    "Format filter server is down or misconfigured" : "Serwer filtrów formatów jest niedostępny lub nieprawidłowo skonfigurowany",
    "Conversion failed. Check log for details." : "Konwersja nieudana. Sprawdź szczegóły w logu.",
    "Saving..." : "Zapisywanie...",
    "Failed to load documents." : "Nie można wczytać dokumentów.",
    "No documents were found. Upload or create a document to get started!" : "Nie znaleziono dokumentów. Wyślij lub stwórz dokument aby rozpocząć!",
    "No connection to server. Trying to reconnect." : "Nie połączono z serwerem. Próba ponownego łączenia. ",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Opuszczając tę stronę w trybie Edytor może spowodować niezapisanie danych. Zaleca się zamiast tego użyć przycisk 'Zamknij'.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Nie można załadować tego dokumentu. Proszę sprawdzić, czy można go otworzyć w zewnętrznym edytorze odt. Może to również oznaczać, że dokument został niedawno zmieniony na nieudostępniony lub usunięty.",
    "Save" : "Zapisz",
    "Loading documents..." : "Ładowanie dokumentów...",
    "'.' is an invalid file name." : "„.” jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nieprawidłowa nazwa. Znaki '\\', '/', '<', '>', ':', '\"', '|', '?' oraz '*' są niedozwolone.",
    "Align Left" : "Wyrównaj do lewej",
    "Alignment" : "Wyrównanie",
    "Align Right" : "Wyrównaj do prawej",
    "Annotate" : "Adnotacje",
    "Background" : "Tło",
    "Bold" : "Pogrubienie",
    "Bottom" : "Dół",
    "Cancel" : "Anuluj",
    "Center" : "Do środka",
    "Clone" : "Klonuj",
    "Clone this Style" : "Klonuj ten styl",
    "Close" : "Zamknij",
    "Color" : "Kolor",
    "Create" : "Utwórz",
    "Decrease Indent" : "Zmniejsz wcięcie",
    "Default Style" : "Domyślny styl",
    "Delete" : "Usuń",
    "Family" : "Rodzina",
    "Font" : "Czcionka",
    "Font Effects" : "Efekty czcionki",
    "Format" : "Format",
    "Increase Indent" : "Zwiększ wcięcie",
    "Insert Image" : "Wstaw obraz",
    "Invite Members" : "Zaproś członków",
    "Italic" : "Kursywa",
    "Justified" : "Wyjustowany",
    "Justify" : "Wyjustuj",
    "Left" : "Lewo",
    "Loading" : "Ładuję",
    "Members" : "Członkowie",
    "New Name:" : "Nowa nazwa:",
    "OK" : "OK",
    "Open" : "Otwórz",
    "Options" : "Opcje",
    "Paragraph..." : "Akapit...",
    "Paragraph Styles" : "Style akapitów",
    "Redo" : "Ponów",
    "Right" : "Prawo",
    "Size" : "Rozmiar",
    "Spacing" : "Odstępy",
    "Strikethrough" : "Przekreślenie",
    "Style" : "Style",
    "Text" : "Tekst",
    "Top" : "Góra",
    "Underline" : "Podkreślenie",
    "Undo" : "Cofnij",
    "Unknown Author" : "Nieznany autor",
    "Shared" : "Udostępniono",
    "Error" : "Błąd",
    "Error while sharing" : "Błąd podczas współdzielenia",
    "Error while unsharing" : "Błąd podczas zatrzymywania współdzielenia",
    "Error while changing permissions" : "Błąd przy zmianie uprawnień",
    "Shared with you and the group {group} by {owner}" : "Udostępnione tobie i grupie {group} przez {owner}",
    "Shared with you by {owner}" : "Udostępnione tobie przez {owner}",
    "Share with users or groups …" : "Współdziel z użytkownikami lub grupami",
    "Share" : "Udostępnij",
    "Share link" : "Udostępnij link",
    "The public link will expire no later than {days} days after it is created" : "Link publiczny wygaśnie nie później niż po {days} dniach od utworzenia",
    "Link" : "Odnośnik",
    "Password protect" : "Zabezpiecz hasłem",
    "Password" : "Hasło",
    "Choose a password for the public link" : "Wybierz hasło dla linku publicznego",
    "Allow editing" : "Pozwól na edycję",
    "Email link to person" : "Wyślij osobie odnośnik poprzez e-mail",
    "Send" : "Wyślij",
    "Set expiration date" : "Ustaw datę wygaśnięcia",
    "Expiration" : "Wygaśnięcie",
    "Expiration date" : "Data wygaśnięcia",
    "Adding user..." : "Dodawanie użytkownika...",
    "group" : "grupa",
    "remote" : "zdalny",
    "Resharing is not allowed" : "Współdzielenie nie jest możliwe",
    "Shared in {item} with {user}" : "Współdzielone w {item} z {user}",
    "Unshare" : "Zatrzymaj współdzielenie",
    "notify by email" : "powiadom przez emaila",
    "can share" : "może współdzielić",
    "can edit" : "może edytować",
    "access control" : "kontrola dostępu",
    "create" : "utwórz",
    "change" : "zmiany",
    "delete" : "skasuj",
    "Password protected" : "Zabezpieczone hasłem",
    "Error unsetting expiration date" : "Błąd podczas usuwania daty wygaśnięcia",
    "Error setting expiration date" : "Błąd podczas ustawiania daty wygaśnięcia",
    "Sending ..." : "Wysyłanie...",
    "Email sent" : "E-mail wysłany",
    "Warning" : "Ostrzeżenie",
    "Edit" : "Edytuj",
    "guest" : "gość",
    "MS Word support (requires openOffice/libreOffice)" : "Wsparcie MS Word (wymaga openOffice/libreOffice)",
    "Local" : "Lokalny",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice jest zainstalowany na tej maszynie. Ścieżka do binariów jest podawana przez preview_libreoffice_path w config.php",
    "External" : "Zewnętrzny",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice jest zainstalowany na zewnętrznym systemie z uruchomionym serwerem konwersji formatów",
    "Disabled" : "Wyłączone",
    "No MS Word support" : "Brak wsparcia dla MS Word",
    "scheme://domain.tld[:port]" : "schemat://domena.tld[:port]",
    "Server URL" : "URL serwera",
    "Apply and test" : "Zastosuj i przetestuj",
    "New document" : "Nowy dokument",
    "Upload (max. %s)" : "Wysyłka (max. %s)",
    "Upload" : "Wyślij",
    "Save new documents to" : "Zapisz nowy dokument do",
    "Wrong password. Please retry." : "Złe hasło. Spróbuj ponownie.",
    "Guest %s" : "Gość %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Ten link już wygasła lub nigdy nie istniał. Proszę skontaktuj się z osobą, która udostępniła ci link, aby uzyskać szczegółowe informacje.",
    "Advanced feature-set" : "Zaawansowany zestaw funkcji",
    "(Unstable)" : "(Niestabilne)"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
